bayespy.inference.vmp.transformations.RotateVaryingMarkovChain.get_bound_terms
==============================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateVaryingMarkovChain.get_bound_terms